@@ -12,7 +12,7 @@ TERMiteRequestBuilder- make requests to the TERMite API and process results.
 """
 
 __author__ = 'SciBite DataScience'
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 __copyright__ = '(c) 2019, SciBite Ltd'
 __license__ = 'Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License'
 
@@ -20,6 +20,7 @@ import requests
 import os
 import pandas as pd
 import json
+import base64
 
 
 class TermiteRequestBuilder():
@@ -48,6 +49,24 @@ class TermiteRequestBuilder():
         """
         self.basic_auth = (username, password)
         self.verify_request = verification
+        
+    def set_oauth2(self, token_user, token_pw, verification = True):
+        """Pass username and password for the Elsevier token api
+        It then uses these credentials to generate an access token and adds 
+        this to the request header.
+        :token_user: username to access Elsevier token api. Specific to the hosting website
+        :token_pw:   password to access Elsevier token api. Specific to the hosting website
+        """
+        auth64 = base64.b64encode(bytearray(token_user+":"+token_pw,'utf8')) #base64 encoded Username+password
+        auth64 = auth64.decode ('utf8')
+            
+        
+        token_address = "https://api.healthcare.elsevier.com:443/token"
+        req = requests.post(token_address, data= {"grant_type": "client_credentials"}, 
+            headers = {"Authorization": "Basic "+ auth64, "Content-Type": "application/x-www-form-urlencoded"})
+        access_token = req.json()['access_token']
+        self.headers = {"Authorization": "Bearer "+ access_token}
+        self.verify_request = verification
 
     def set_url(self, url):
         """
@@ -204,12 +223,23 @@ class TermiteRequestBuilder():
             print("REQUEST: ", self.url, self.payload)
         try:
             if self.binary_content and bool(self.basic_auth):
+                #Basic authentication request for binary content
                 response = requests.post(self.url, data=self.payload, files=self.binary_content, auth=self.basic_auth,
                                          verify=self.verify_request)
-            elif self.binary_content and bool(self.basic_auth) == False:
+
+            elif self.binary_content and bool(self.basic_auth) == False and bool(self.headers):
+                #OAuth2 authentication request for binary content
+                response = requests.post(self.url, data=self.payload, files=self.binary_content, 
+                                         verify=self.verify_request, headers=self.headers)
+            elif self.binary_content and bool(self.basic_auth) == False and bool(self.headers) == False:
+                #No authentication request for binary content
                 response = requests.post(self.url, data=self.payload, files=self.binary_content)
             elif not self.binary_content and bool(self.basic_auth):
+                #Basic authentication for text content
                 response = requests.post(self.url, data=self.payload, verify=self.verify_request, auth=self.basic_auth)
+            elif not self.binary_content and bool(self.headers):
+                #OAuth2 authentication request for text content
+                response = requests.post(self.url, data=self.payload, verify=self.verify_request, headers=self.headers)
             else:
                 response = requests.post(self.url, data=self.payload)
         except Exception as e:
